==> nosql-database_24.4.zip: nosql-database_24.4_20241213/content/kvlocal/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Documentation Accessibility",
                    "href":"shared-global-topic-documentation-accessibility.html"
                },
                {
                    "title":"Introduction",
                    "href":"introduction-kvlocal.html"
                },
                {
                    "title":"Java Development Kit (JDK) Requirements",
                    "href":"jdk-requirement.html"
                },
                {
                    "title":"Embedding KVLocal in your Java Application",
                    "href":"embedding-kvlocal-your-java-application.html"
                },
                {
                    "title":"Starting Administration CLI",
                    "href":"starting-administration-cli.html"
                },
                {
                    "title":"Running SQL Shell with KVLocal",
                    "href":"running-sql-shell-kvlocal.html"
                },
                {
                    "title":"Backing Up KVLocal Store",
                    "href":"backing-kvlocal-store.html"
                },
                {
                    "title":"KVLocal Diagnostic Utility",
                    "href":"kvlocal-diagnostic-utility.html",
                    "topics":[
                        {
                            "title":"Sample JSON output from Diagnostic Utility",
                            "href":"sample-json-output-diagnostic-utility.html"
                        }
                    ]
                },
                {
                    "title":"KVLocal FAQs",
                    "href":"kvlocal-faqs.html"
                }
            ]
        }
    ]
});

==> nosql-database_25.3.zip: nosql-database_25.3_20251015/content/kvlocal/toc.js <==
define(
{
    "reducedVersion":true,
    "toc":[
        {
            "heading":"Table of Contents",
            "topics":[
                {
                    "title":"Title and Copyright Information",
                    "href":"index.html"
                },
                {
                    "title":"Documentation Accessibility",
                    "href":"do-not-use-shared-global-topic-documentation-accessibility.html"
                },
                {
                    "title":"Introduction",
                    "href":"introduction-kvlocal.html"
                },
                {
                    "title":"Java Development Kit (JDK) Requirements",
                    "href":"jdk-requirement.html"
                },
                {
                    "title":"Embedding KVLocal in your Java Application",
                    "href":"embedding-kvlocal-your-java-application.html"
                },
                {
                    "title":"Starting Administration CLI",
                    "href":"starting-administration-cli.html"
                },
                {
                    "title":"Running SQL Shell with KVLocal",
                    "href":"running-sql-shell-kvlocal.html"
                },
                {
                    "title":"Backing Up KVLocal Store",
                    "href":"backing-kvlocal-store.html"
                },
                {
                    "title":"KVLocal Diagnostic Utility",
                    "href":"kvlocal-diagnostic-utility.html",
                    "topics":[
                        {
                            "title":"Sample JSON output from Diagnostic Utility",
                            "href":"sample-json-output-diagnostic-utility.html"
                        }
                    ]
                },
                {
                    "title":"KVLocal FAQs",
                    "href":"kvlocal-faqs.html"
                }
            ]
        }
    ]
});
